import { __assign } from './../external/tslib/tslib.es6.js';
import React from 'react';
import { parseMetadata, suffixMetadata } from '@highlight-ui/utils-commons';
import { Icon } from '@highlight-ui/icon';
import { Button } from '@highlight-ui/button';
import { Tooltip } from '@highlight-ui/tooltip';
import { Checkbox } from '@highlight-ui/checkbox';
import { Link } from '@highlight-ui/link';
import { Typography } from '@highlight-ui/typography';
import classnames from 'classnames';
import styles from './FileList.module.scss.js';
var FileList = /*#__PURE__*/React.forwardRef(function (_a, ref) {
  var className = _a.className,
      metadata = _a.metadata,
      files = _a.files,
      onDelete = _a.onDelete,
      variant = _a.variant,
      onSelect = _a.onSelect,
      selectedItems = _a.selectedItems;
  return /*#__PURE__*/React.createElement("div", __assign({
    className: classnames(styles.fileList, className),
    ref: ref
  }, parseMetadata(metadata)), files.map(function (file) {
    var _a, _b;

    return /*#__PURE__*/React.createElement("div", __assign({
      key: file.id,
      className: styles.fileItem
    }, parseMetadata(suffixMetadata(metadata, 'fileitem'))), /*#__PURE__*/React.createElement("div", {
      className: classnames(styles.fileItemInfo, (_a = {}, _a[styles.precedingCheckbox] = variant === 'selectable' && file.validationMessage, _a))
    }, file.validationStatus === 'validating' && !file.validationMessage ? /*#__PURE__*/React.createElement(Icon, {
      name: "spinner-third",
      size: 14,
      type: "solid",
      color: "icon-highlight",
      spin: true,
      metadata: suffixMetadata(metadata, 'loading-indicator')
    }) : /*#__PURE__*/React.createElement(React.Fragment, null, variant === 'selectable' && /*#__PURE__*/React.createElement("div", {
      className: styles.checkboxWrapper
    }, /*#__PURE__*/React.createElement(Checkbox, {
      metadata: suffixMetadata(metadata, 'fileitem-checkbox'),
      onChange: function () {
        return onSelect && onSelect(file.id);
      },
      checked: selectedItems === null || selectedItems === void 0 ? void 0 : selectedItems.some(function (item) {
        return item === file.id;
      })
    })), file.validationMessage && /*#__PURE__*/React.createElement(Tooltip, {
      content: file.validationMessage,
      placement: "bottom"
    }, /*#__PURE__*/React.createElement("span", __assign({
      className: styles.tooltipIcon
    }, parseMetadata(suffixMetadata(metadata, "tooltip-" + (file.validationStatus === 'invalid' ? 'error' : 'warning')))), /*#__PURE__*/React.createElement(Icon, {
      name: file.validationStatus === 'invalid' ? 'exclamation-circle' : 'exclamation-triangle',
      size: 14,
      type: "solid",
      color: file.validationStatus === 'invalid' ? 'icon-critical' : 'icon-warning'
    }))))), file.validationStatus === 'validating' || file.validationStatus !== 'valid' || !file.previewUrl ? /*#__PURE__*/React.createElement(Typography, {
      variant: "body-1",
      component: "p",
      className: classnames(styles.fileItemName, (_b = {}, _b[styles.fileItemIsLoading] = file.validationStatus === 'validating', _b[styles.fileItemNotValid] = file.validationStatus !== 'validating', _b))
    }, file.filename) : /*#__PURE__*/React.createElement(Link, {
      href: file.previewUrl,
      target: "_blank",
      rel: "noopener noreferrer",
      className: styles.fileItemName
    }, file.filename), /*#__PURE__*/React.createElement("div", {
      className: styles.fileItemActions
    }, file.validationStatus === 'valid' && file.downloadUrl && /*#__PURE__*/React.createElement(Link, {
      target: "_blank",
      rel: "noopener noreferrer",
      href: file.downloadUrl,
      className: styles.buttonIcon,
      metadata: {
        testId: "download-" + file.id
      }
    }, /*#__PURE__*/React.createElement(Icon, {
      name: "download",
      size: 14,
      type: "solid",
      color: "icon-default"
    })), file.canDelete && /*#__PURE__*/React.createElement(Button, {
      variant: "default",
      className: styles.buttonIcon,
      onClick: function () {
        return onDelete && onDelete(file.id);
      },
      metadata: suffixMetadata(metadata, 'fileitem-delete-action'),
      buttonState: file.validationStatus === 'validating' ? 'disabled' : 'enabled'
    }, /*#__PURE__*/React.createElement(Icon, {
      name: "trash",
      size: 14,
      type: "solid",
      color: "icon-default"
    }))));
  }));
});
export { FileList };
//# sourceMappingURL=FileList.js.map
